<?php

namespace Litecms\Trading\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Trading\Models\TradingSetting;

class TradingSettingPolicy
{

    /**
     * Determine if the given user can view the trading_setting.
     *
     * @param UserPolicy $user
     * @param TradingSetting $trading_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, TradingSetting $trading_setting)
    {
        if ($user->canDo('trading.trading_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $trading_setting->user_id == user_id() && $trading_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a trading_setting.
     *
     * @param UserPolicy $user
     * @param TradingSetting $trading_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('trading.trading_setting.create');
    }

    /**
     * Determine if the given user can update the given trading_setting.
     *
     * @param UserPolicy $user
     * @param TradingSetting $trading_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, TradingSetting $trading_setting)
    {
        if ($user->canDo('trading.trading_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $trading_setting->user_id == user_id() && $trading_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given trading_setting.
     *
     * @param UserPolicy $user
     * @param TradingSetting $trading_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TradingSetting $trading_setting)
    {
        return $trading_setting->user_id == user_id() && $trading_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given trading_setting.
     *
     * @param UserPolicy $user
     * @param TradingSetting $trading_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TradingSetting $trading_setting)
    {
        if ($user->canDo('trading.trading_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given trading_setting.
     *
     * @param UserPolicy $user
     * @param TradingSetting $trading_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TradingSetting $trading_setting)
    {
        if ($user->canDo('trading.trading_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
